/*
 * defs.h for kdrill
 *   Okay, I lied.. this file has struct definitions, as
 *   well as the #defines
 */
extern int errno;

/* for reading in kanjidic lines */
#define MAXLINELEN 1024

/* how many possible answers are there? */
#define NUMBEROFCHOICES 5

/* enum for "changemode()" */
enum { GUESSMEANING, GUESSKANJI,TOGGLEKANA};

#define STATUSDISTANCE 20
#define BUTTONSWIDTH 105
#define GRADEDISTANCE 14

#define ALLGRADES 0xfe
#define ABOVESIXGRADE 0x80
/* FULLWIDTH is startup size of an english translation button */
#define FULLWIDTH 370

#define MINKANJIALLOWED 0x2000
#define MAXKANJIALLOWED 0x8000
#define HAVE_AT_LEAST 9

struct translationstruct {

	char *english;	/* english translation string.
			 * null-terminated.
			 * Can theoretically be any length, but
			 * since it will all be on a single-line
			 * text widget, that would be silly
			 */

	int frequency;		/* frequency that kanji is used */
	int grade_level;	/* akin to  school class level */
	XChar2b *pronunciation;

};

/********************************************************************

SO here's the format for the translation/dictionary file I have decided
on so far:

I changed specs. it will have to be in "kanjidic" format...

Two char high-bit-set identifier, followed by JIS number in hex.
Followed by stroke information? [HAS TO BE TERMINATED BY 'Gx', where
				  'x' is any number]
Followed by pronunciation guide, in kana.
Followed by various english translations, enclosed in {}

"kanjidic" often has multiple {} phrases. which leads to another nasty
hack  in readstructs()

*/
